@@ -8,7 +8,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-use version 0.77; our $VERSION = version->declare("v0.9.4");
+use version 0.77; our $VERSION = version->declare("v0.9.5");
 
 __PACKAGE__->setting(
     handle_static => 1,
@@ -53,7 +53,8 @@ get '/{match:(?:[-_a-zA-Z0-9]+(?:\.[0-9]+)?.html)?}' => sub {
     });
 };
 
-get '/entry/{name:[-_a-zA-Z0-9/]+}.html' => sub {
+my $s = '[-_a-zA-Z0-9]+';
+get "/entry/{name:$s(?:\.$s)*(?:/$s(?:\.$s)*)*}.html" => sub {
     my ($c, $args) = @_;
 
     my $name = $args->{name};
